# Advanced Concepts


* [Defining new processor](define_processor.md)


* [Library Architecture](library_architecture.md)


    * [Events](library_architecture.md#events)


    * [Dataset](library_architecture.md#dataset)


    * [Feature Definition](library_architecture.md#feature-definition)


    * [Processors](library_architecture.md#processors)


    * [RxPY](library_architecture.md#rxpy)
